pub fn persist_pause(path: &Path, state: &PauseState)Expand description
Atomically write the current pause state to disk. The deadline is stored as an absolute epoch timestamp so a paused-until-X is honoured across process restarts.
pub fn persist_pause(path: &Path, state: &PauseState)Atomically write the current pause state to disk. The deadline is stored as an absolute epoch timestamp so a paused-until-X is honoured across process restarts.