pub fn persist_screen_time(path: &Path, state: &ScreenTimeState)Expand description
Atomically write state to disk. Called every tick that the
counter changes, plus on rollover and after firing a reminder.
pub fn persist_screen_time(path: &Path, state: &ScreenTimeState)Atomically write state to disk. Called every tick that the
counter changes, plus on rollover and after firing a reminder.