pub fn postpone_counter(t: &BreakTimers, kind: BreakKind) -> u32Expand description
How many times the user has postponed the current break of this
kind. Sleep always returns 0 (sleep prompts don’t escalate).
pub fn postpone_counter(t: &BreakTimers, kind: BreakKind) -> u32How many times the user has postponed the current break of this
kind. Sleep always returns 0 (sleep prompts don’t escalate).